%define major 3
%define libname %mklibname %{name}2_ %{major}
%define develname %mklibname -d %{name}
%define variant_version 1.1.6

Name:      mapnik
Version:   3.1.0
Release:   %mkrel 12
Summary:   Free Toolkit for developing mapping applications
Group:     Geography
License:   LGPLv2+
URL:       http://mapnik.org/
Source0:   https://github.com/mapnik/mapnik/releases/download/v%{version}/mapnik-v%{version}.tar.xz
Source1:   https://github.com/mapbox/variant/archive/v%{variant_version}/variant-%{variant_version}.tar.xz
Source2:   no_date_footer.html
Source3:   mapnik-data.license
Source4:   viewer.desktop
BuildRequires: postgresql-devel
BuildRequires: postgis
BuildRequires: pkgconfig
BuildRequires: gdal-devel
BuildRequires: proj-devel
BuildRequires: agg-devel
BuildRequires: scons
BuildRequires: doxygen
BuildRequires: desktop-file-utils
BuildRequires: libltdl-devel
BuildRequires: qt4-devel
BuildRequires: libxml2-devel
BuildRequires: boost-devel
BuildRequires: libicu-devel
BuildRequires: libtiff-devel
BuildRequires: libjpeg-devel
BuildRequires: libpng-devel
BuildRequires: cairomm-devel
BuildRequires: python-cairo-devel
BuildRequires: freetype2-devel
BuildRequires: python-devel
BuildRequires: pkgconfig(harfbuzz)
BuildRequires: pkgconfig(libwebp)
Requires:  fonts-ttf-dejavu
Requires: %{libname} = %{version}-%{release}
ExcludeArch: %{ix86}
Provides: bundled(agg) = 2.4

%description
Mapnik is a Free Toolkit for developing mapping applications.
It's written in C++ and there are Python bindings to
facilitate fast-paced agile development. It can comfortably
be used for both desktop and web development, which was something
I wanted from the beginning.

Mapnik is about making beautiful maps. It uses the AGG library
and offers world class anti-aliasing rendering with subpixel
accuracy for geographic data. It is written from scratch in
modern C++ and doesn't suffer from design decisions made a decade
ago. When it comes to handling common software tasks such as memory
management, filesystem access, regular expressions, parsing and so
on, Mapnik doesn't re-invent the wheel, but utilises best of breed
industry standard libraries from boost.org

%package -n %{libname}
Summary: Mapnik is a Free toolkit for developing mapping applications
Group: System/Libraries

%description -n %{libname}
Mapnik is a Free Toolkit for developing mapping applications.
It's written in C++ and there are Python bindings to
facilitate fast-paced agile development. It can comfortably
be used for both desktop and web development, which was something
I wanted from the beginning.

Mapnik is about making beautiful maps. It uses the AGG library
and offers world class anti-aliasing rendering with subpixel
accuracy for geographic data. It is written from scratch in
modern C++ and doesn't suffer from design decisions made a decade
ago. When it comes to handling common software tasks such as memory
management, filesystem access, regular expressions, parsing and so
on, Mapnik doesn't re-invent the wheel, but utilises best of breed
industry standard libraries from boost.org


%package -n %{develname}
Summary: Mapnik is a Free toolkit for developing mapping applications
Group: Development/Libraries
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Obsoletes: %{name}-devel

%description -n %{develname}
Mapnik is a Free Toolkit for developing mapping applications.
It's written in C++ and there are Python bindings to
facilitate fast-paced agile development. It can comfortably
be used for both desktop and web development, which was something
I wanted from the beginning.

Mapnik is about making beautiful maps. It uses the AGG library
and offers world class anti-aliasing rendering with subpixel
accuracy for geographic data. It is written from scratch in
modern C++ and doesn't suffer from design decisions made a decade
ago. When it comes to handling common software tasks such as memory
management, filesystem access, regular expressions, parsing and so
on, Mapnik doesn't re-invent the wheel, but utilises best of breed
industry standard libraries from boost.org

%package python
Summary:  Python bindings for the Mapnik spatial visualization library
License:  GPLv2+
Group:    Development/Python
Requires: %{name} = %{version}-%{release}
Requires: python-imaging python-lxml

%description python
Language bindings to enable the Mapnik library to be used from python

%package utils
License:  GPLv2+
Summary:  Utilities distributed with the Mapnik spatial visualization library
Group:    Geography
Requires: %{name} = %{version}-%{release}

%description utils
Miscellaneous utilities distributed with the Mapnik spatial visualization
library

%prep
%setup -q -b1 -n %{name}-v%{version}
%autopatch -p1

rm -rf deps/mapbox/variant
ln -sf %{_builddir}/variant-%{variant_version} deps/mapbox/variant

rm -fr demo

%build

./configure   DESTDIR=%{buildroot} \
              PREFIX=%{_prefix} \
              LIBDIR_SCHEMA=%{buildroot}/%{_libdir} \
              THREADING=multi \
              XMLPARSER=libxml2 \
              GDAL_INCLUDES=%{_includedir}/gdal \
              CUSTOM_CFLAGS="%{optflags} -DACCEPT_USE_OF_DEPRECATED_PROJ_API_H" \
              CUSTOM_CXXFLAGS="%{optflags} -DACCEPT_USE_OF_DEPRECATED_PROJ_API_H" \
              CUSTOM_LDFLAGS="%{ldflags}" \
              SYSTEM_FONTS=%{_datadir}/fonts \
              DEMO=False

%make_build

%install
rm -rf %buildroot
%make_install

# get rid of fonts use external instead
rm -rf %{buildroot}%{_libdir}/%{name}/fonts

# install more utils
mkdir -p %{buildroot}%{_bindir}

# install pkgconfig file
cat > %{name}.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
includedir=%{_includedir}

Name: %{name}
Description: Free Toolkit for developing mapping applications
Version: %{version}
Libs: -lmapnik
Cflags: -I${includedir}/%{name}
EOF

mkdir -p %{buildroot}%{_datadir}/pkgconfig/
install -p -m 644 %{name}.pc %{buildroot}%{_datadir}/pkgconfig/


%files
%doc AUTHORS.md COPYING CHANGELOG.md
%{_libdir}/%{name}

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*
%{_libdir}/lib%{name}.so.%{version}

%files -n %{develname}
%{_bindir}/mapnik-config
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_datadir}/pkgconfig/%{name}.pc

%files python


%files utils
%{_bindir}/shapeindex
%{_bindir}/mapnik-render
%{_bindir}/mapnik-index
%{_libdir}/libmapnik-json.a
%{_libdir}/libmapnik-wkt.a


%changelog
* Wed Dec 27 2023 pp - 3.1.0-12pclos2024
- rebuild against new gdal

* Thu May 11 2023 pp - 3.1.0-11pclos2023
- rebuild against new gdal

* Thu Dec 08 2022 pp - 3.1.0-10pclos2022
- rebuild against new gdal, proj

* Sun Sep 18 2022 tex - 3.1.0-9pclos2022
- rebuild against updates

* Tue Sep 13 2022 tex - 3.1.0-8pclos2022
- rebuild against updates

* Sat May 14 2022 pp <pp> 3.1.0-7pclos2022
- rebuild against new gdal

* Mon Mar 14 2022 pp <pp> 3.1.0-6pclos2022
- rebuild against new proj

* Wed Nov 10 2021 pp <pp> 3.1.0-5pclos2021
- rebuild against new gdal

* Sun Sep 26 2021 tex - 3.1.0-4pclos2021
- rebuild against new boost

* Sat Jul 03 2021 pp <pp> 3.1.0-3pclos2021
- rebuild against new proj

* Mon May 10 2021 pp <pp> 3.1.0-2pclos2021
- rebuild against new gdal

* Sun Mar 07 2021 pp <pp> 3.1.0-1pclos2021
- update

* Wed Nov 04 2020 pp <pp> 3.0.23-3pclos2020
- rebuild against new gdal, proj

* Fri Jul 03 2020 pp <pp> 3.0.23-2pclos2020
- rebuild against new gdal

* Sun Apr 19 2020 pp <pp> 3.0.23-1pclos2020
- update

* Sat May 18 2019 pp <pp> 3.0.22-1pclos2019
- update

* Wed Mar 20 2019 pp <pp> 3.0.15-3pclos2019
- rebuild against updates

* Mon Mar 04 2019 tex - 3.0.15-2pclos2019
- rebuild against updates

* Tue Oct 31 2017 bb2 <bb2> - 3.0.15-1pclos2017
- import into pclos for gpsd and viking
